Examples
========

Here are some simple examples that will show how to use some of the Apex methods
and support functions.

.. toctree::

   examples/ex_init.rst
   examples/ex_cli.rst
   examples/ex_apexh.rst
   examples/ex_gc.rst
